@@ -1,3 +1,4 @@
+import asyncio
 from abstract_apis import get_url,make_endpoint
 def getSolcatcherUrl():
   return 'https://solcatcher.io'
@@ -15,3 +16,9 @@ def ifListGetSection(listObj,section=0):
         if len(listObj)>section:
             return listObj[section]
     return listObj
+def get_async_response(func, *args, **kwargs):
+    if asyncio.get_event_loop().is_running():
+        # If already inside an event loop, use ensure_future or create_task
+        return asyncio.ensure_future(func(*args, **kwargs))
+    else:
+        return asyncio.run(func(*args, **kwargs))
